C	FUNCTION AREA
C       MODIFIED BY MARK WOLFIRE
C
C	PURPOSE
C	  INTEGRATE THE AREA BENEATH A SET OF DATA POINTS
C
C	USAGE
C         RESULT = AREA (X, Y, NPTS, NTERMS)
C
C	DESCRIPTION OF PARAMETERS
C	  X      - ARRAY OF DATA POINTS FOR INDEPENDENT VARIABLE
C	  Y      - ARRAY OF DATA POINTS FOR DEPENDENT VARIABLE
C         NPTS   - NUMBER OF PAIRS OF DATA POINTS
C         NTERMS - NUMBER OF TERMS IN FITTING POLYNOMIAL
C
C	SUBROUTINES AND FUNCTION SUBPROGRAMS REQUIRED
C	  INTEG (X, Y, NTERMS, I1, X1, X2, SUM)
C	    FITS A POLYNOMIAL WITH NTERMS STARTING AT I1
C	    AND INTEGRATES AREA FROM X1 TO X2
C
C	MODIFICATIONS FOR FORTRAN II
C	  OMIT DOUBLE PRECISION SPECIFICATIONS
	FUNCTION AREA (X, Y, NPTS, NTERMS)
	DOUBLE PRECISION SUM
	DIMENSION X(1), Y(1)
11	SUM = 0.
	IF(NPTS - NTERMS) 21, 21, 13
13	NEVEN = 2*(NTERMS/2)
	IDELTA = NTERMS/2 - 1
	IF(NTERMS - NEVEN) 31, 31, 51
C	  
C	  FIT ALL POINTS WITH ONE CURVE
C
21	X1 = X(1)
	X2 = X(NPTS)
23	CALL INTEG (X, Y, NPTS, 1, X1, X2, SUM)
	GO TO 71
C
C	  EVEN NUMBER OF TERMS
C
31	X1 = X(1)
	J = NTERMS - IDELTA
	X2 = X(J)
	CALL INTEG (X, Y, NTERMS, 1, X1, X2, SUM)
	I1 =  NPTS - NTERMS + 1
	J = I1 + IDELTA
	X1 = X(J)
	X2 = X(NPTS)
39	CALL INTEG(X, Y, NTERMS, I1, X1, X2, SUM)
	IF ( I1 - 2) 71, 71, 41
41	IMAX = I1 - 1
	DO 46 I=2, IMAX
	J = I + IDELTA
	X1 = X(J)
	X2 = X(J+1)
46	CALL INTEG (X, Y, NTERMS, I, X1, X2, SUM)
	GO TO 71
C
C	  ODD NUMBER OF TERMS
C
51	X1 = X(1)
	J = NTERMS - IDELTA
	X2 = (X(J) + X(J-1))/2.
	CALL INTEG (X, Y, NTERMS, 1, X1, X2, SUM)
	I1 = NPTS - NTERMS + 1 
	J = I1 + IDELTA
	X1 = (X(J) + X(J+1))/2.
	X2 = X(NPTS)
59	CALL INTEG (X, Y, NTERMS, I1, X1, X2, SUM)
	IF (I1 - 2) 71, 71, 61
61	IMAX = I1 - 1
	DO 66 I=2, IMAX
	J = I + IDELTA
	X1 = (X(J+1) + X(J))/2.
	X2 = (X(J+2) + X(J+1))/2.
66	CALL INTEG (X, Y, NTERMS, I, X1, X2, SUM)
71	AREA = SUM
	RETURN
	END	
C
C 	SUBROUTINE INTEG
C
C	PURPOSE
C	  INTEGRATE THE AREA BENEATH TWO DATA POINTS
C
C	USAGE
C	  CALL INTEG (X, Y, NTERMS, I1, X1, X2, SUM)
C
C	DESCRIPTION OF PARAMETERS
C	  X      - ARRAY OF DATA POINTS FOR INDEPENDENT VARIABLE
C         Y      - ARRAY OF DATA POINTS FOR DEPENDENT VARIABLE
C         NTERMS - NUMBER OF TERMS IN FITTING POLYNOMIAL
C         I1     - FIRST DATA POINT FOR FITTING POLYNOMIAL
C         X1     - FIRST VALUE OF X FOR INTEGRATION
C	  X2     - FINAL VALUE OF X FOR INTEGRATION
C
C	SUBROUTINES AND FUNCTION SUBPROGRAMS REQUIRED
C	  NONE
C
C	MODIFICATIONS FOR FORTRAN II
C	  OMIT DOUBLE PRECISION
C
C	COMMENTS
C	  DIMENSION STATEMENT VALID FOR NTERMS UP TO 10
C
	SUBROUTINE INTEG (X, Y, NTERMS, I1, X1, X2, SUM)
	DOUBLE PRECISION XJK, ARRAY, A, DENOM, DELTAX, SUM
	DIMENSION X(1), Y(1)
	DIMENSION ARRAY(50,50)
C
C	  CONSTRUCT SQUARE MATRIX AND INVERT
C		
11	DO 17 J=1,NTERMS
	I = J + I1 - 1
	DELTAX = X(I) - X(I1)
	XJK = 1.0
	DO 17 K=1, NTERMS
	ARRAY(J,K) = XJK
17	XJK = XJK * DELTAX
21	CALL MATINV (ARRAY, NTERMS, DET)
	IF (DET) 31, 23, 31
23	IMID = I1 + NTERMS/2
	WRITE(6,*)'DET = 0'
	SUM = SUM + Y(IMID)*(X2-X1)
	GO TO 40
C
C	  EVALUATE COEFFICIENTS AND INTEGRATE
C
31	DX1 = X1 - X(I1)
	DX2 = X2 - X(I1)
33	DO 39 J=1, NTERMS
C	I = J + I1 - 1
	A = 0.
	DO 37 K=1, NTERMS
C         ** NOTE ERROR IN BEVINGTON'S CODE **
C         DEPENDENT VARIABLE K IS ACCUMULATED FOR EACH 
C         POLYNOMIAL COEFFICIENT J .
	I = K +I1-1
37	A = A + Y(I)*ARRAY(J,K)
	DENOM = J
39	SUM = SUM + (A/DENOM)*(DX2**J - DX1**J)
40	RETURN
	END
	SUBROUTINE MATINV (ARRAY, NORDER, DET)
	DOUBLE PRECISION ARRAY, AMAX, SAVE
	DIMENSION ARRAY(50,50), IK(50),JK(50)
10	DET = 1.0
11	DO 100 K=1,NORDER
C
C	  FIND LARGEST ELEMENT ARRAY(I,J) IN REST OF MATRIX
C
	AMAX = 0.
21	DO 30 I=K, NORDER
	DO 30 J=K, NORDER
23	IF (DABS(AMAX) - DABS(ARRAY(I,J))) 24, 24, 30
24	AMAX = ARRAY(I,J)	
	IK(K) = I
	JK(K) = J
30	CONTINUE
C
C	  INTERCHANGE ROWS
C 
31	IF (AMAX) 41, 32, 41
32	DET = 0.
	GO TO 140
41	I = IK(K)
	IF (I-K) 21, 51, 43
43	DO 50 J=1, NORDER
	SAVE = ARRAY(K,J)
	ARRAY(K,J) = ARRAY(I,J)
50	ARRAY(I,J) = -SAVE
51	J = JK(K)
	IF(J-K) 21, 61, 53
53	DO 60 I=1, NORDER
	SAVE = ARRAY(I,K)
	ARRAY(I,K) = ARRAY(I,J)
60	ARRAY(I,J) = -SAVE
C
C	  ACCUMULATE
C
61	DO 70 I=1, NORDER
	IF (I-K) 63, 70, 63
63	ARRAY(I,K) = -ARRAY(I,K)/AMAX
70	CONTINUE
71	DO 80 I=1, NORDER
	DO 80 J=1, NORDER
	IF (I-K) 74, 80, 74
74	IF (J-K) 75, 80, 75
75	ARRAY(I,J) = ARRAY(I,J) + ARRAY(I,K)*ARRAY(K,J)
80	CONTINUE
81	DO 90 J=1, NORDER
	IF (J-K) 83, 90, 83
83	ARRAY(K,J) = ARRAY(K,J)/AMAX
90	CONTINUE
        ARRAY(K,K) = 1./AMAX
100	DET = DET * AMAX
C 
C	  RESTORE
C
101	DO 130 L=1, NORDER
	K = NORDER - L + 1
	J = IK(K)
	IF (J-K) 111, 111, 105
105	DO 110, I=1, NORDER
	SAVE = ARRAY(I,K)
	ARRAY(I,K) = -ARRAY(I,J)
110	ARRAY(I,J) = SAVE
111	I = JK(K)
	IF (I-K) 130, 130, 113
113	DO 120 J=1, NORDER
	SAVE = ARRAY(K,J)
	ARRAY(K,J) = -ARRAY(I,J)
120	ARRAY(I,J) = SAVE
130	CONTINUE
140	RETURN
	END
