        Program hpw
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
C Program to take intensity as a function of impact parameter
C   and calculate the integrated flux in increasing beam sizes. 
C   Set dist = 500 pc for flux and radial profile. Proper scaleing
C              is done in perl script
C  
C  Complete set of impact parameters are read from data 
C    file rfptot.dat, and a shortned set are returned in rfp.dat
C
C Note:  Make sure that the impact parameters are all different. 
C        Sometimes the round off error in rfp.dat causes
C        two adjacent impact parameters to be the same. This will 
C        cause  the program to generate a bunch of NaNs.
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
        double precision ah1,ah0,cz,c1,ah,bh
        double precision amu1,amu0,d1,d2
        dimension fjy(200,21),fwhmp(200),ahi(500)
        dimension ainp12(50000),ajys(200)
        dimension pl(200),p(200),afluxt(500)
        dimension beami(50000),api(50000),aints(200)
        dimension aint(500),amu(500),ahr(200,21),aht(21)
        dimension alam(150),dum1(150),dum2(150),dum4(150),dum7(150)
        dimension alnu(150)
        character*200 aline1,aline2,aline3
        character*70  alinrw1,alinrw2,alinrw3
        open(10,status='old',file='rfptot.dat')
        open(11,status='old',file='flowpart.dat')
        open(12,status='old',file='rfp.dat')
        open(20,status='unknown',file='jy.dat')
        open(25,status='old',file='fnews.out')
        open(26,status='old',file='fnew.out')
        pi = 3.1415926
        pc = 3.085e18
        srarc = 180.0/pi*3600.0
        dist = 0.50*pc*1.0e3
c nfreq is number of frequencies written out to display
        nfreq = 21
        nfrq100=12
        nfreqmx = 83
c Read in indexes to write out in case of failed model
        read(11,5001)aline1
        read(11,5001)aline1
        read(11,5001)aline1
        read(11,5001)aline1
        read(11,*)ips,il1,il2,it1,it2,it3,ior1,ior2,ior3,iav1,
     &    iav2,iir1,iir2
c Read in intensties  (SHELL + STELLAR) at all impact parameters
C npmax is read from data file rfptot.dat
        read(10,*)npmax 
        read(10,5001)aline1
        read(10,5001)aline2
        read(10,5001)aline3
        do 10 ip = 1,npmax
c for ISRF ahr might be negative
           read(10,*)p(ip),(ahr(ip,ifreq),ifreq=1,nfreq)
 10     continue
C read in stellar intensity at p = 0
        read(25,*)reff,(ajys(ifreq),ifreq=1,nfreq)
C read in shell intensity at p = 0 and overwrite array ahr(1,ifreq)
C which is stellar + shell intensity. 
        read(25,*)reff,(ahr(1,ifreq),ifreq=1,nfreq)
C read in total flux at wavelength grid and interpolated wavelengths
        read(25,*)reff,(aht(ifreq),ifreq=1,nfreq)
        do 7 ifreq = 1,nfreq
           aht(ifreq) = aht(ifreq)*(p(npmax)/dist)**2/1.0E-23
 7      continue
        p(1) = 0.0
        do 30 ifreq=1,nfreq
c Convert stellar intensity at p = 0 to stellar flux
           aints(ifreq) = ajys(ifreq)
           ajys(ifreq) = ajys(ifreq)*(reff/dist)**2*pi/1.0E-23
           fwhm = 1.0
           beamf = 1.5
           ifwhmmx = 25
           do 25 ifwhm =1,ifwhmmx
             sum = 0.0
             delv = fwhm/(2.0*sqrt(alog(2.0)))
             fwhmp(ifwhm)=fwhm
             amu1 = 1.0
             amu(1) = amu1
             ah1=ahr(1,ifreq)
             do 19 ipc = 1,npmax
                amu0 = dsqrt(1.-DBLE((p(ipc)/p(npmax))**2))
                ps = (p(ipc)/dist)*srarc
                expt = ps/delv
                if(expt.gt.8)expt=8.0
                ah0 = ahr(ipc,ifreq)*exp(-(expt**2))
                if(ah0.lt.1.0E-32)ah0=1.0E-32
                amu(ipc) = amu0
                cz = amu0
                c1 = amu1
                ah = c1*ah0 -cz*ah1
                bh = ah1-ah0
                d1 = cz+c1
                d2 = C1**2+C1*CZ+CZ**2
                sum = sum + SNGL(0.5*ah*d1 +bh*d2/3.)
                amu1 = amu0
                ah1 = ah0
 19          continue
C convert to true flux (4x pi H)
             ahout2 = 0.5*sum*4.0*pi
C write out flux (including stellar flux at p=0)
             fjy(ifwhm,ifreq) = ahout2*(p(npmax)/dist)**2/1.0e-23
     .                          +ajys(ifreq)
             fwhm = fwhm*beamf
 25       continue
 30    continue
C  Check error in 100 um flux at maximum beam size
       delerr = abs((aht(nfrq100)-fjy(ifwhmmx,nfrq100))/
     &          aht(nfrq100))
C If error greater than 10% then model is failed 
       if(delerr.gt.0.10)then
          OPEN(UNIT=27,STATUS='UNKNOWN',FILE='failed.out')
          WRITE(27,*)ips,il1,il2,it1,it2,it3,
     &  ior1,ior2,ior3,iav1,iav2,iir1,iir2,'  FAILED-hpw ',delerr
          close(27)
        else
          do 37 ifreq=1,nfreq
          fact = aht(ifreq)/fjy(ifwhmmx,ifreq)
          do 37 ifwhm = 1, ifwhmmx
          fjy(ifwhm,ifreq) = fjy(ifwhm,ifreq)*fact
 37     continue
        write(25,*)delerr
        end if
        WRITE(20,*)'FWHM F F F F F F F F F F F F F F F F F F F F F'   
        WRITE(20,*)'NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC 
     . NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC 
     . NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC'
        WRITE(20,*)'[arcsec] [2.2um] [3.6um] [4.8um] [5.8um] [8.0um] 
     . [9.7um] [12um] [14.2um] [19um] [25um] [60um] [100um] [158um] 
     . [200um] [370um] [450um] [610um] [800um] [1.0mm] [1.3mm] [2.6mm] '
       do 35 ifwhm=1,ifwhmmx
       write(20,1000)fwhmp(ifwhm),(fjy(ifwhm,ifreq),ifreq=1,nfreq)
c       write(6,1000)fwhmp(ifwhm),(fjy(ifwhm,ifreq),ifreq=1,nfreq)
 35     continue
 1000   format(22(1PE10.3))
C  Check error in SED for dropout in flux 
        read(26,5002)alinrw1
        read(26,5002)alinrw2
        read(26,5002)alinrw3
        do 36 inu = 1,nfreqmx
        read(26,*)dum1(inu),dum2(inu),afluxt(inu),dum4(inu),
     &           alnu(inu),alam(inu),dum7(inu)
 36   continue
      close(26)
C  test for single dropout in flux at all wavelengths
C  if single dropout use average
       iave = 0
       do 41 il = 2,nfreqmx
        if((afluxt(il-1).gt.5.0E-27).and.(afluxt(il).lt.5.0E-27).
     1    and.(afluxt(il+1).gt.5.0E-27))then
            iave = 1
            afluxt(il) = 0.5*(afluxt(il-1)+afluxt(il+1))
            alnu(il) = 0.5*(alnu(il-1)+alnu(il+1))
         end if
 41      continue
C  test for additional dropouts skipping lambda near 10 um feature
C  models fail for additional dropouts
        do 42 inu=2,nfreqmx
        if((alam(inu).gt.11.5).or.(alam(inu).lt.7.5))then
           if((afluxt(inu).gt.5.0E-27).and.
     &           (afluxt(inu-1).lt.3.0E-28)) then
           OPEN(UNIT=27,STATUS='UNKNOWN',FILE='failed.out')
           WRITE(27,*)ips,il1,il2,it1,it2,it3,
     &   ior1,ior2,ior3,iav1,iav2,iir1,iir2,'  FAILED-hpwsed'
            close(27)
            end if
        end if
 42   continue
c if iave eq. 1 then new file needs to be written
        if(iave.eq.1) then
        open(26,status='old',file='fnew.out')
          write(26,5002)alinrw1
          write(26,5002)alinrw2
          write(26,5002)alinrw3
          do 43 il=1,nfreqmx
            write(26,1500)dum1(il),dum2(il),afluxt(il),dum4(il),
     1      alnu(il),alam(il),dum7(il)
 43       continue
 1500      format(' ',1PE10.3,1PE10.3,5(1PE10.3))
       end if        
c end test
C write out new rfp.dat file with fewer impact parameters and 
C  stellar intensity at reff and shell intensties everywhere else 
        close(10)
c check for negative (?) rfp and set to 1.0E-30
        do 39 ip=1,npmax
        do 39 ifreq=1,nfreq
        if(ahr(ip,ifreq).lt.0.0)ahr(ip,ifreq)=1.0E-32
 39     continue
        WRITE(12,*)'p I I I I I I I I I I I I I I I I I I I I I'
        WRITE(12,*)'NUMERIC NUMERIC NUMERIC NUMERIC 
     .  NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC
     .  NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC 
     .  NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC'
        WRITE(12,*)'[cm] [2.2um] [3.6um] [4.8um] [5.8um] [8.0um] 
     . [9.7um] [12um] [14.2um] [19um] [25um] [60um] [100um] [158um] 
     . [200um] [370um] [450um] [610um] [800um] [1.0mm] [1.3mm] [2.6mm] '
        ip = 1
        write(12,5000)reff,(ahr(ip,ifreq)+aints(ifreq),
     +         ifreq=1,nfreq)
        do 40 ip = 2,npmax,5
           write(12,5000)p(ip),(ahr(ip,ifreq),ifreq=1,nfreq)
 40    continue
 5000  format(' ',22(1PE10.3))
 5001  format(A200)
 5002  format(A70)
       stop
        end




