        Program hpw
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
C Program to take intensity as a function of impact parameter
C   and calculate the integrated flux in increasing beam sizes. 
C   Set dist = 500 pc for flux and radial profile. Proper scaleing
C              is done in perl script
C
C  Modifed version for MIPS bands
C  
C  Complete set of impact parameters are read from data 
C    file rfpallf.dat, and a shortned set are returned in rfpmips.dat
C
C Note:  Make sure that the impact parameters are all different. 
C        Sometimes the round off error in rfp.dat causes
C        two adjacent impact parameters to be the same. This will 
C        cause  the program to generate a bunch of NaNs.
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
        double precision ah1,ah0,cz,c1,ah,bh
        double precision amu1,amu0,d1,d2
        dimension fjy(200,21),fwhmp(200)
        dimension ainp12(50000),ajys(200)
        dimension alam0(4)
        dimension p(200),afluxt(500),freq(150),tau(150),fnus(150)
        dimension beami(50000),api(50000),aints(200)
        dimension aint(500),amu(500),ahr(200,150),aht(150)
        dimension alam(150),dum1(150),dum2(150),dum4(150),dum7(150)
        dimension alnu(150),ahrmips(200,150),ahtmips(150),ajysmips(200)
        character*200 aline1,aline2,aline3
        character*70  alinrw1,alinrw2,alinrw3
        open(10,status='old',file='rfpallf.dat')
        open(11,status='old',file='flowpart.dat')
        open(12,status='unknown',file='rfpmips.dat')
        open(23,status='unknown',file='jymips.dat')
        open(25,status='old',file='fnewsallf.out')
        open(26,status='unknown',file='fnewmips.out')
        open(30,status='old',file='fnew.out')
        pi = 3.1415926
        pc = 3.085e18
        srarc = 180.0/pi*3600.0
        dist = 0.50*pc*1.0e3
c nfreq is number of frequencies in instrument bands
        nfreq = 3
        nfrq8=3
        nfreqmx = 83
c Read in indexes to write out in case of failed model
        read(11,5001)aline1
        read(11,5001)aline1
        read(11,5001)aline1
        read(11,5001)aline1
        read(11,*)ips,il1,il2,it1,it2,it3,ior1,ior2,ior3,iav1,
     &    iav2,iir1,iir2
c Read in intensties  (SHELL + STELLAR) at all impact parameters
C npmax is read from data file rfptot.dat
        read(10,*)npmax 
        do 10 ip = 1,npmax
           read(10,*)p(ip),(ahr(ip,ifreq),ifreq=1,nfreqmx)
           do ifreq=1,nfreqmx
c needs to be non negative for log interpolation
              if(ahr(ip,ifreq).le.0.0)ahr(ip,ifreq) = 1.0e-28
           enddo
 10     continue
C read in stellar intensity at p = 0
        read(25,*)reff,(ajys(ifreq),ifreq=1,nfreqmx)
C read in shell intensity at p = 0 and overwrite array ahr(1,ifreq)
C which is stellar + shell intensity. 
        read(25,*)reff,(ahr(1,ifreq),ifreq=1,nfreqmx)
C read in total flux at wavelength grid
        read(25,*)reff,(aht(ifreq),ifreq=1,nfreqmx)
        do ifreq=1,nfreqmx
c needs to be non negative for log interpolation
           if(ajys(ifreq).le.0.0)ajys(ifreq)=1.0e-28
           if(ahr(1,ifreq).le.0.0)ahr(1,ifreq)=1.0e-28
        enddo
C read in frequency array
        read(25,*)(freq(ifreq),ifreq=1,nfreqmx)
        do iband = 1,nfreq
           call mipscol(ahr,ahrmips,ajys,ajysmips,aht,ahtmips,
     .       freq,nfreqmx,npmax,alam0,iband)
        end do
        do 7 ifreq = 1,nfreq
           ahtmips(ifreq) = ahtmips(ifreq)*
     .                            (p(npmax)/dist)**2/1.0E-23
 7      continue
        p(1) = 0.0
        do 30 ifreq=1,nfreq
c Convert stellar intensity at p = 0 to stellar flux
           aints(ifreq) = ajysmips(ifreq)
           ajysmips(ifreq) = ajysmips(ifreq)*(reff/dist)**2*
     .                       pi/1.0E-23
           fwhm = 1.0
           beamf = 1.5
           ifwhmmx = 25
           do 25 ifwhm =1,ifwhmmx
             sum = 0.0
             delv = fwhm/(2.0*sqrt(alog(2.0)))
             fwhmp(ifwhm)=fwhm
             amu1 = 1.0
             amu(1) = amu1
c shell intensity I+ - I- alone 
             ah1=ahrmips(1,ifreq)
             do 19 ipc = 1,npmax
                amu0 = dsqrt(1.-DBLE((p(ipc)/p(npmax))**2))
                ps = (p(ipc)/dist)*srarc
                expt = ps/delv
                if(expt.gt.8)expt=8.0
                ah0 = ahrmips(ipc,ifreq)*exp(-(expt**2))
                if(ah0.lt.1.0E-32)ah0=1.0E-32
                amu(ipc) = amu0
                cz = amu0
                c1 = amu1
                ah = c1*ah0 -cz*ah1
                bh = ah1-ah0
                d1 = cz+c1
                d2 = C1**2+C1*CZ+CZ**2
                sum = sum + SNGL(0.5*ah*d1 +bh*d2/3.)
                amu1 = amu0
                ah1 = ah0
 19          continue
C convert to true flux (4x pi H)
             ahout2 = 0.5*sum*4.0*pi
C write out flux (including stellar flux at p=0)
C total flux (ahtmips) was set to 1.0e-28 for neg (absorption) 
C if total flux is negative set sum Shell + Star to 1.0e-28 for 
c all beam sizes
             fjyt = ahtmips(ifreq)/((p(npmax)/dist)**2)*1.0E-23
             if(fjyt.gt.1.3e-28)then
                fjy(ifwhm,ifreq) = ahout2*(p(npmax)/dist)**2/1.0e-23
     .                          +ajysmips(ifreq)
             else
                fjy(ifwhm,ifreq) = 1.0e-28
             endif
             fwhm = fwhm*beamf
25       continue
 30    continue

C  Check error in Band 3  flux at maximum beam size
       delerr = abs((ahtmips(nfrq8)-fjy(ifwhmmx,nfrq8))/
     &          ahtmips(nfrq8))
C If error greater than 10% and flux greater than 1e-28 then model is failed 
       fjyt = ahtmips(nfrq8)/((p(npmax)/dist)**2)*1.0E-23
       if(delerr.gt.0.10.and.fjyt.gt.1.3e-28 )then
          OPEN(UNIT=27,STATUS='UNKNOWN',FILE='failed.out')
          WRITE(27,*)ips,il1,il2,it1,it2,it3,
     &  ior1,ior2,ior3,iav1,iav2,iir1,iir2,'  FAILED-hpw-mips ',
     &  delerr
          close(27)
        else
          do 37 ifreq=1,nfreq
c use factor only for non negative flux in largest beam
          fjyt = ahtmips(ifreq)/((p(npmax)/dist)**2)*1.0E-23
          if(fjyt.gt.1.3e-28)then
             fact = ahtmips(ifreq)/fjy(ifwhmmx,ifreq)
          else 
             fact = 1.0
          endif
          do 37 ifwhm = 1, ifwhmmx
          fjy(ifwhm,ifreq) = fjy(ifwhm,ifreq)*fact
 37     continue
        write(25,*)delerr
        end if
C Write out MIPS flux versus beam size
        WRITE(23,*)'FWHM F F F'   
        WRITE(23,*)'NUMERIC NUMERIC NUMERIC NUMERIC'
        WRITE(23,*)'[arcsec] [MIPS 24] [MIPS 70] [MIPS 160]'
       do 35 ifwhm=1,ifwhmmx
       write(23,1000)fwhmp(ifwhm),(fjy(ifwhm,ifreq),ifreq=1,nfreq)
c       write(6,1000)fwhmp(ifwhm),(fjy(ifwhm,ifreq),ifreq=1,nfreq)
 35     continue
 1000   format(5(1PE10.3))
        close(10)
C Write out MIPS intensities versus impact parameter (short list of p)
c        WRITE(12,*)'p I I I'
c        WRITE(12,*)'NUMERIC NUMERIC NUMERIC NUMERIC'
c        WRITE(12,*)'[cm] [MIPS 24] [MIPS 70] [MIPS 160]'
c        ip = 1
c        write(12,5000)reff,(ahrmips(ip,ifreq)+aints(ifreq),
c     +         ifreq=1,nfreq)
c        do 40 ip = 2,npmax,5
c           write(12,5000)p(ip),(ahrmips(ip,ifreq),ifreq=1,nfreq)
c 40    continue
C Write out MIPS intensities versus impact parameter all p
        WRITE(12,*)'p I I I'
        WRITE(12,*)'NUMERIC NUMERIC NUMERIC NUMERIC'
        WRITE(12,*)'[cm] [MIPS 24] [MIPS 70] [MIPS 160]'
        ip = 1
        write(12,5000)reff,(ahrmips(ip,ifreq)+aints(ifreq),
     +         ifreq=1,nfreq)
        do 41 ip = 2,npmax
           write(12,5000)p(ip),(ahrmips(ip,ifreq),ifreq=1,nfreq)
 41     continue
C Write out MIPS freq,mag,flux,optical dpeth,luminosity,wavelength,stellar flux
        read(30,5004)aline3
        read(30,5004)aline3
        read(30,5004)aline3
        do 45 ifreq=1,nfreqmx
           read(30,*)dumnu,av,dumfnu,tau(ifreq),dumlnu,dummu,fnus(ifreq)
 45     continue
        WRITE(26,*) '   Freq Av Fnu Tau Lnu Lambda Fnus '
        WRITE(26,*)' NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC NUMERIC 
     &  NUMERIC '
        WRITE(26,*)' [Hz] [mag] [erg/cm2/s/Hz]  []  [erg/s/Hz] [mu]  
     & [erg/cm2/s/Hz] '
        do 46 ifreq=1,nfreq
           anuband = 2.997925e14/alam0(ifreq)
           call interp(freq,tau,nfreqmx,2,anuband,tauband)
           call interp(freq,fnus,nfreqmx,2,anuband,fnusband)
           fnu = ahtmips(ifreq)*1.0e-23*(dist/p(npmax))**2
           alumn = alog10(fnu) + alog10(4.0*pi) + 
     &                  2.0*alog10(p(npmax))
           write(26,5003)anuband,av,fnu,tauband,alumn,
     &                 alam0(ifreq),fnusband

 46     continue
 5000  format(' ',5(1PE10.3))
 5001  format(A200)
 5002  format(A70)
 5004   format(A5)
 5003   FORMAT(' ',1PE10.3,1PE10.3,5(1PE10.3))
       close(26)
       close(30)
       stop
        end





