      subroutine iraccol(ahr,ahrirac,ajys,ajysirac,aht,ahtirac,
     .       freq,nfreqmx,npmax,alam0,iband)
C iraccol(scattered,thermal,dirbewvl,aracint,iband)
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
C  Subroutine to return IRAC band averaged intensity in MJy/sr
C  written by Mark Wolfire
C
C  Input Parameters:
C  ================
C    iband     = IRAC band number
C                1 : 3.6 um band
C                2 : 4.5 um band
C                3 : 5.8 um band
C                4 : 8.0 um band
C
C  Outputs:
C  =======
C    aracint  = intensity at IRAC band center assuming I_nu x nu = constant
C                (MJy/sr) i.e. "quoted" intensities where 
C               I_nu (quoted) = K x I_nu (actual) and K is calculated
C               as in Units and Conventions by Bill Reach.  Integration 
C               constants = integral [ (nu_0/nu) R/nu dnu] are precalculated
C               and stored in bandint.
C
C   Notes:
C   =====
C   IRAC band filters R are read in as needed 
C        irac_tr1.dat = IRAC band 1
C        irac_tr2.dat = IRAC band 2
C        irac_tr3.dat = IRAC band 3
C        irac_tr4.dat = IRAC band 4
C   Intensity is interpolated between model frequency grid
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
        dimension scattered(3),thermal(8),dirbewvl(10)
        dimension wave(201),tran(201),aint(201),ainu(201),aint1(201)
        dimension bandint(4),alam0(4)
        dimension freq(83),ahr(200,150),ahrirac(200,150),ajys(200)
        dimension ahri(200),freql(83),ahtl(150),ajysl(200)
        dimension ajysirac(200),aht(150),ahtirac(150)
        character*12 datafile
        character*1 ib
        integer iband
        real lambda,ipd
        integer i 
C-----------------------------------------------------------------------------
C   Precalculated integration constants for each IRAC band
C----------------------------------------------------------------------------
C Constants for R
        data bandint/0.126918256,0.143180043,0.064407073,0.139533788/
C Constants for R_nu
c        data bandint/1.08712E+13,9.53873E12,3.32909E12,5.22890E+12/
        c = 2.997925e14
C----------------------------------------------------------------------------
C   Open IRAC band response data file
C----------------------------------------------------------------------------
        write(ib,'(I1)')iband
        datafile = 'irac_tr'//ib//'.dat'
        open(unit=20,status='old',file=datafile)
C----------------------------------------------------------------------------
C  Start integration loop for each wavelength in filter response file
C  Loop calculates I_nu x R where I_nu is intensity interpolated between
C  frequency grid
C----------------------------------------------------------------------------
C----------------------------------------------------------------------------
C  Read in response response function and wavelength and determine
C  wavelength of band center (see Bill Reach memo).
        read(20,*)nlines
        do il = 1,nlines
           inu = nlines + 1 -il 
           read(20,*)wave(il),tran(inu)
           ainu(inu) = c/wave(il)
           aint(inu) = tran(inu)*(wave(il)/ainu(inu))
           aint1(inu) = tran(inu)/ainu(inu)
        end do
        call oneteg(ainu,aint,alnum,nlines)
        call oneteg(ainu,aint1,alden,nlines)
        alam0(iband) =(alnum/alden)
C  End response function loop
C----------------------------------------------------------------------------

C  Loop over frequecies to generate log values for
C  interpolation
       do ifreq = 1,nfreqmx
          freql(ifreq) = alog10(freq(ifreq))
          ahtl(ifreq)  = alog10(aht(ifreq))
          ajysl(ifreq) = alog10(ajys(ifreq))  
       end do

C  Loop over Intensities (shell + stellar)
C  Loop over impact parameter
       do impct = 1,npmax
         do ifreq = 1,nfreqmx
            ahri(ifreq) = alog10((ahr(impct,ifreq)))
         end do
C-----------------------------------------------------------------------------
C Loop over number of wavelengths in response table
         do inu = 1,nlines
            call interp(freql,ahri,nfreqmx,2,alog10(ainu(inu)),out)
C Integral assumes response function is electrons/photon
            aint(inu) = 10.00**out*tran(inu)/ainu(inu)
C Integral assumes response function is per Hz
c            aint(inu) = out*tran(inu)/ainu(inu)
         end do
C End loop over response table
C-----------------------------------------------------------------------------
C Integrated intensity over bandpass
        call oneteg(ainu,aint,aracint,nlines)
        aracint = aracint/bandint(iband)
        ahrirac(impct,iband) = aracint
       end do 
C End loop over impact parameter

C------------------------------------------------------------------------------
C Loop over stellar intensities
         do inu = 1,nlines
            call interp(freql,ajysl,nfreqmx,2,alog10(ainu(inu)),out)
C Integral assumes response function is electrons/photon
            aint(inu) = 10.00**out*tran(inu)/ainu(inu)
C Integral assumes response function is per Hz
c            aint(inu) = out*tran(inu)
         end do
        call oneteg(ainu,aint,aracint,nlines)
        aracint = aracint/bandint(iband)
        ajysirac(iband) = aracint
C End Loop over stellar intensities
C------------------------------------------------------------------------------

C-----------------------------------------------------------------------------
C  Loop over total flux
         do inu = 1,nlines
            call interp(freql,ahtl,nfreqmx,2,alog10(ainu(inu)),out)
C Integral assumes response function is electrons/photon
            aint(inu) = 10.00**out*tran(inu)/ainu(inu)
C Integral assumes response function is per Hz
c            aint(inu) = out*tran(inu)
         end do
        call oneteg(ainu,aint,aracint,nlines)
        aracint = aracint/bandint(iband)
        ahtirac(iband) = aracint
C End loop over total flux
C------------------------------------------------------------------------------
        close(20)
        return
        end

c	SUBROUTINE ONETEG(X,Y,TEG,NPOINT)
c	DIMENSION X(1),Y(1)
c	TEG = 0.0
c	DO 10 I=2,NPOINT
c	TEG = TEG + 0.5*(Y(I)+Y(I-1))*(X(I)-X(I-1))	
c10	CONTINUE
c	RETURN
c	END
