      subroutine mipscol(ahr,ahrmips,ajys,ajysmips,aht,ahtmips,
     .       freq,nfreqmx,npmax,alam0,iband)
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
C  Subroutine to return MIPS band averaged intensity in MJy/sr
C  written by Mark Wolfire
C
C  Input Parameters:
C  ================
C    iband     = MIPS band number
C                1 : 24 um band
C                2 : 70 um band
C                3 :160 um band
C
C  Outputs:
C  =======
C    aracint  = intensity at MIPS band center assuming I_nu x nu = constant
C                (MJy/sr) i.e. "quoted" intensities where 
C               I_nu (quoted) = K x I_nu (actual) and K is calculated
C               as in Units and Conventions by Bill Reach.  Integration 
C               constants = integral [ (nu_0/nu) R/nu dnu] are precalculated
C               and stored in bandint.
C
C   Notes:
C   =====
C   MIPS band filters R are read in as needed 
C        mips_tr1.dat = MIPS band 1
C        mips_tr2.dat = MIPS band 2
C        mips_tr3.dat = MIPS band 3
C   Intensity is interpolated between model frequency grid
C^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
        dimension scattered(3),thermal(8),dirbewvl(10)
        dimension wave(401),tran(401),aint(401),ainu(401),aint1(401)
        dimension bandint(3),alam0(4)
        dimension freq(150),ahr(200,150),ahrmips(200,150),ajys(200)
        dimension ahri(200),freql(150),ahtl(150),ajysl(200)
        dimension ajysmips(200),aht(150),ahtmips(150)
        character*12 datafile
        character*1 ib
        integer iband
        real lambda,ipd
        integer i 
C-----------------------------------------------------------------------------
C   Precalculated integration constants for each MIPS band
C----------------------------------------------------------------------------
C Constants for R
        data bandint/0.223705649,0.298438281,0.229339838/
        c = 2.997925e14
C----------------------------------------------------------------------------
C   Open MIPS band response data file
C----------------------------------------------------------------------------
        write(ib,'(I1)')iband
        datafile = 'mips_tr'//ib//'.dat'
        open(unit=20,status='old',file=datafile)
C----------------------------------------------------------------------------
C  Start integration loop for each wavelength in filter response file
C  Loop calculates I_nu x R where I_nu is intensity interpolated between
C  frequency grid
C----------------------------------------------------------------------------
C----------------------------------------------------------------------------
C  Read in response response function and wavelength and determine
C  wavelength of band center (see Bill Reach memo).
        read(20,*)nlines
        do il = 1,nlines
           inu = nlines + 1 -il 
           read(20,*)wave(il),tran(inu)
           ainu(inu) = c/wave(il)
           aint(inu) = tran(inu)*(wave(il)/ainu(inu))
           aint1(inu) = tran(inu)/ainu(inu)
        end do
        call oneteg(ainu,aint,alnum,nlines)
        call oneteg(ainu,aint1,alden,nlines)
        alam0(iband) =(alnum/alden)
C  End response function loop
C----------------------------------------------------------------------------

C  Loop over frequecies to generate log values for
C  interpolation
       do ifreq = 1,nfreqmx
          freql(ifreq) = alog10(freq(ifreq))
          ahtl(ifreq)  = alog10(aht(ifreq))
          ajysl(ifreq) = alog10(ajys(ifreq))  
       end do

C  Loop over Intensities (shell + stellar)
C  Loop over impact parameter
       do impct = 1,npmax
         do ifreq = 1,nfreqmx
            ahri(ifreq) = alog10(ahr(impct,ifreq))
         end do
C-----------------------------------------------------------------------------
C Loop over number of wavelengths in response table
         do inu = 1,nlines
            call interp(freql,ahri,nfreqmx,2,alog10(ainu(inu)),out)
C Integral assumes response function is electrons/photon
            aint(inu) = 10.00**out*tran(inu)/ainu(inu)
C Integral assumes response function is per Hz
c            aint(inu) = out*tran(inu)/ainu(inu)
         end do
C End loop over response table
C-----------------------------------------------------------------------------
C Integrated intensity over bandpass
        call oneteg(ainu,aint,aracint,nlines)
        aracint = aracint/bandint(iband)
        ahrmips(impct,iband) = aracint
       end do 
C End loop over impact parameter

C------------------------------------------------------------------------------
C Loop over stellar intensities
         do inu = 1,nlines
            call interp(freql,ajysl,nfreqmx,2,alog10(ainu(inu)),out)
C Integral assumes response function is electrons/photon
            aint(inu) = 10.00**out*tran(inu)/ainu(inu)
C Integral assumes response function is per Hz
c            aint(inu) = out*tran(inu)
         end do
        call oneteg(ainu,aint,aracint,nlines)
        aracint = aracint/bandint(iband)
        ajysmips(iband) = aracint
C End Loop over stellar intensities
C------------------------------------------------------------------------------

C-----------------------------------------------------------------------------
C  Loop over total flux
         do inu = 1,nlines
            call interp(freql,ahtl,nfreqmx,2,alog10(ainu(inu)),out)
C Integral assumes response function is electrons/photon
            aint(inu) = 10.00**out*tran(inu)/ainu(inu)
C Integral assumes response function is per Hz
c            aint(inu) = out*tran(inu)
         end do
        call oneteg(ainu,aint,aracint,nlines)
        aracint = aracint/bandint(iband)
        ahtmips(iband) = aracint
C End loop over total flux
C------------------------------------------------------------------------------
        close(20)
        return
        end

c	SUBROUTINE ONETEG(X,Y,TEG,NPOINT)
c	DIMENSION X(1),Y(1)
c	TEG = 0.0
c	DO 10 I=2,NPOINT
c	TEG = TEG + 0.5*(Y(I)+Y(I-1))*(X(I)-X(I-1))	
c10	CONTINUE
c	RETURN
c	END
